@@ -1,5 +1,5 @@
 #!/bin/sh
 cd ent
 ./entest -t
-../src/haveged -r 16384 -v 1 $*
+../src/haveged -n 16384k -v 1 $*
 ./entest -vf sample
